#
# spec file for package python-parfive
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-parfive
Version:        2.0.2
Release:        1.3
Summary:        A HTTP and FTP parallel file downloader
License:        MIT
URL:            https://parfive.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/p/parfive/parfive-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module aioftp >= 0.17.1}
BuildRequires:  %{python_module aiofiles}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-localserver}
BuildRequires:  %{python_module pytest-socket}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tqdm >= 4.27.0}
# /SECTION
Requires:       python-aiohttp
Requires:       python-tqdm
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-aiofiles
Recommends:     python-aioftp
BuildArch:      noarch

%python_subpackages

%description
Parfive is a library for downloading files, its objective is to
provide an API for queuing files for download and then providing
feedback to the user about the downloads in progress. It also
provides an interface for inspecting any failed downloads.

%prep
%autosetup -p1 -n parfive-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/parfive

%check
# Disable tests that require a network connection
%pytest -k 'not test_ftp and not test_ftp_http'

%post
%python_install_alternative parfive

%postun
%python_uninstall_alternative parfive

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/parfive
%{python_sitelib}/parfive-%{version}.dist-info
%python_alternative %{_bindir}/parfive

%changelog
* Wed Aug  2 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.2:
  * Vendor parse_header out of the deprecated cgi module for Python 3.11
    compatibility
  * Fix a bug where an asyncio.CancelledError was not properly caught
  * The file_progress, notebook, use_aiofiles, and header keyword arguments
    to parfive.Downloader have been removed and moved into the
    parfive.SessionConfig object.
  * The timeouts keyword argument has been removed from the run_download()
    and download() methods and replaced by an option in SessionConfig.
  * Add a new SessionConfig object to allow advanced configuration of the
    Downloader
  * Improve the CLI with more options
  * Use tqdm's auto notebook detection
  * Fix issue with small files where the size of a chunk would round down to
    0 bytes
  * Remove the default download timeout of 5 minutes for a single file
  * Cast timeout environment variables to numbers
  * Add a Downloader.simple_download method to easily download a list of
    URLs to a single directory
  * Add support for optionally using aiofiles to write files to disk.
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
* Fri Apr  9 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.3.0
  * Add environment variable based options to help with debugging
    @Cadair (#70)
  * Any errors encountered downloading files are now logged to the
    built in python logging system at the INFO level @dstansby (#58)
  * Change use of ensure_future to newer create_task @1nF0rmed (#62)
  * Infra Changes @nabobalis (#68)
- Release 1.2.0
  * Make parfive.Downloader.run_download public API and move all of
    the parfive.Downloader.download logic into run_download. This
    enabled using parfive from inside an async context. (#54)
  * Handing a custom loop to Downloader now does nothing, and
    parfive spins up its own loop. This is to prepare for python
    3.10 where support for passing custom loops to various asyncio
    methods will be removed. (#53)
  * Fix a bug where downloads fail if max_conn is changed after
    construction of the parfive.Downloader instance. (#56)
- Skip python36: support ceased, no aioftp
* Tue Jun 23 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.1.0:
  * Features
    + Add concurent requests to parfive. This feature splits the download of a single file into multiple parts if the server the file is being downloaded from supports ranged requests. This should improve the performance of all downloads under these circumstances, and also make parfive useful even if downloading a single file. No changes are needed to use this feature, files will be downloaded using 12 concurrent requests by default. To change the number of concurrent requests you can pass max_splits to parfive.Downloader.enqueue_file. (#15)
    + Added CLI interface to Parfive. (#16)
    + Parfive now only supports Python 3.6+. (#22)
    + Support for specifying headers to be used for all requests to parfive.Downloader has been added. (#32)
    + Support for HTTP_PROXY and HTTPS_PROXY environment variables have been added. (#32)
  * Bugfixes
    + Fix a bug where running parfive in the notebook would error if ipywidgets was not installed. (#25)
    + Remove use of the deprecated loop= keyword argument to aiohttp.ClientSession. (#30)
    + Update the notebook detection function due to changes in tqdm (#36)
    + Reduce the number of parallel connections to 25 (5 parallel files, 5 parallel downloads per file). (#37)
- Sprinkle in update-alternatives for parfive wrapper.
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Use expanded description.
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
- Initial version
